@@ -1,4 +1,5 @@
 """ Caching database implementations """
+from functools import partial
 from pyramid.path import DottedNameResolver
 
 from .base import ICache
@@ -6,8 +7,9 @@ from .redis_cache import RedisCache
 from .sql import SQLCache
 
 
-def get_cache_impl(settings):
+def includeme(config):
     """ Get and configure the cache db wrapper """
+    settings = config.get_settings()
     resolver = DottedNameResolver(__name__)
     dotted_cache = settings.get('pypi.db', 'sql')
     if dotted_cache == 'sql':
@@ -17,6 +19,9 @@ def get_cache_impl(settings):
     elif dotted_cache == 'dynamo':
         dotted_cache = 'pypicloud.cache.dynamo.DynamoCache'
     cache_impl = resolver.resolve(dotted_cache)
-    cache_impl.configure(settings)
-    cache_impl.reload_if_needed()
+    kwargs = cache_impl.configure(settings)
+    cache = cache_impl(**kwargs)
+    cache.reload_if_needed()
+    config.add_request_method(partial(cache_impl, **kwargs), name='db',
+                              reify=True)
     return cache_impl
